==> tfann-0.5.1.tar.gz: example/README.md <==
# Examples
## sine.dart

```dart

import 'dart:convert';
import 'dart:math';

import 'package:tfann/tfann.dart';

void main() {
  {
    Random r = Random();
    final sine_net = TfannNetwork.full([1, 32, 16, 1],
        [ActivationFunctionType.fastBell, ActivationFunctionType.uscls, ActivationFunctionType.uscsls]);
    for (int i = 0; i < 400000; ++i) {
      var x = r.nextDouble() * 6.29 - 3.145;
      sine_net.train(TrainSetInputOutput.lists([x], [sin(x)]),
          learningRate: 0.02);
    }
    var x = -3.145;
    for (int i = 0; i < 1000; ++i) {
      
      x += 6.29 / 1000;
      print(
          "x= $x : error= ${sine_net.calculateMeanAbsoluteError(
            [TrainSetInputOutput.lists([x], [sin(x)])]).single}");
    }
  }
}

```

## circle.dart

```dart

import 'dart:convert';
import 'dart:math';

import 'package:tfann/tfann.dart';

void main() {
  {
    Random r = Random();
    final circle_net = TfannNetwork.full([
      2,
      32,
      16,
      16,
      1
    ], [
      ActivationFunctionType.fastBell,
      ActivationFunctionType.uscls,
      ActivationFunctionType.uscls,
      ActivationFunctionType.uscsls
    ]);
    var criteria = (sr) => (sr < 1 && sr > 0.25) ? 1.0 : 0.0;
    for (int i = 0; i < 1000000; ++i) {
      var x = r.nextDouble() * 3 - 1.5;
      var y = r.nextDouble() * 3 - 1.5;
      var sr = x * x + y * y;
      circle_net.train(TrainSetInputOutput.lists([x, y], [criteria(sr)]),
          learningRate: 0.02);
    }
    int false_positive = 0;
    int false_negative = 0;
    int testLength = 50000;
    for (int i = 0; i < testLength; ++i) {
      var x = r.nextDouble() * 3 - 1.5;
      var y = r.nextDouble() * 3 - 1.5;
      var sr = x * x + y * y;
      var netResult = circle_net.feedForward(FVector.fromList([x, y])).single;
      if (sr < 1 && sr > 0.25) if (netResult < 0.8) {
        false_negative++;
      }
      if (!(sr < 1 && sr > 0.25)) if (netResult > 0.2) {
        false_positive++;
      }
    }
    print(
        "False Positive: ${false_positive * 100 / testLength}%   False Negative: ${false_negative * 100 / testLength}%");
  }
}

```

==> tfann-0.5.2.tar.gz: example/README.md <==
# Examples
## sine.dart

```dart

import 'dart:convert';
import 'dart:math';

import 'package:tfann/tfann.dart';

void main() {
  {
    Random r = Random();
    final sine_net = TfannNetwork.full([1, 32, 16, 1],
        [ActivationFunctionType.fastBell, ActivationFunctionType.uscls, ActivationFunctionType.uscsls]);
    for (int i = 0; i < 400000; ++i) {
      var x = r.nextDouble() * 6.29 - 3.145;
      sine_net.train(TrainSetInputOutput.lists([x], [sin(x)]),
          learningRate: 0.02);
    }
    var x = -3.145;
    for (int i = 0; i < 1000; ++i) {
      
      x += 6.29 / 1000;
      print(
          "x= $x : error= ${sine_net.calculateMeanAbsoluteError(
            [TrainSetInputOutput.lists([x], [sin(x)])]).single}");
    }
  }
}

```

## circle.dart

```dart

import 'dart:convert';
import 'dart:math';

import 'package:tfann/tfann.dart';

void main() {
  {
    Random r = Random();
    final circle_net = TfannNetwork.full([
      2,
      32,
      16,
      16,
      1
    ], [
      ActivationFunctionType.uscls,
      ActivationFunctionType.fastBell,
      ActivationFunctionType.uscls,
      ActivationFunctionType.fastBell
    ]);
    var criteria = (sr) => (sr < 1 && sr > 0.25) ? 1.0 : 0.0;
    for (int i = 0; i < 2000000; ++i) {
      var x = r.nextDouble() * 3 - 1.5;
      var y = r.nextDouble() * 3 - 1.5;
      var sr = x * x + y * y;
      circle_net.train(TrainSetInputOutput.lists([x, y], [criteria(sr)]),
          learningRate: 0.02);
    }
    int false_positive = 0;
    int false_negative = 0;
    int testLength = 50000;
    for (int i = 0; i < testLength; ++i) {
      var x = r.nextDouble() * 3 - 1.5;
      var y = r.nextDouble() * 3 - 1.5;
      var sr = x * x + y * y;
      var netResult = circle_net.feedForward(FVector.fromList([x, y])).single;
      if (sr < 1 && sr > 0.25) if (netResult < 0.8) {
        false_negative++;
      }
      if (!(sr < 1 && sr > 0.25)) if (netResult > 0.2) {
        false_positive++;
      }
    }
    print(
        "False Positive: ${false_positive * 100 / testLength}%   False Negative: ${false_negative * 100 / testLength}%");
  }
}

```

## bitwise.dart

```dart

import 'dart:convert';
import 'dart:math';

import 'package:tfann/tfann.dart';

void main() {


  List<TrainSetInputOutput> bw_data = [
    /*  output: column  1 - XOR of 3 bits, column  2 - AND of 3 bits,
      column  3 - OR of 3 bits, column  4 - if exactly two bits ON,
    */
    TrainSetInputOutput.lists([-1, -1, -1], [0, 0, 0, 0]),
    TrainSetInputOutput.lists([1, 1, -1], [0, 0, 1, 1]),
    TrainSetInputOutput.lists([1, -1, -1], [1, 0, 1, 0]),
    TrainSetInputOutput.lists([-1, 1, -1], [1, 0, 1, 0]),
    TrainSetInputOutput.lists([-1, -1, 1], [1, 0, 1, 0]),
    TrainSetInputOutput.lists([1, 1, 1], [1, 1, 1, 0]),
    TrainSetInputOutput.lists([1, -1, 1], [0, 0, 1, 1]),
    TrainSetInputOutput.lists([-1, 1, 1], [0, 0, 1, 1]),
  ];

  final bwise_net =
      TfannNetwork.full([3, 5, 4], [ActivationFunctionType.uscsls, ActivationFunctionType.uscsls]);
  // train network
  for (int i = 0; i < 7000; ++i) {
    bw_data.forEach((data) {
      bwise_net.train(data, learningRate: 0.06);
    });
  }

  print("after training...");

    
  bw_data.forEach((data) => print(
    "in: ${data.input.toList()} out: ${bwise_net.feedForward(data.input).toList()} expected: ${data.output.toList()}"));

  print("generated code:");
  print(compileNetwork(bwise_net));

}

```
